@@ -13,13 +13,14 @@ from super_eureka import logging
 def create_driver() -> Chrome:
     user_data_dir = os.getenv('CHROME_USER_DATA_DIR')
     profile_folder = os.getenv('CHROME_PROFILE_FOLDER')
+    chromedriver_path = os.getenv('CHROMEDRIVER_PATH')
     
     options = ChromeOptions()
     options.add_argument(f'--user-data-dir={user_data_dir}')
     options.add_argument(f'--profile-folder={profile_folder}')
     options.headless = False
 
-    driver = Chrome(executable_path='./chromedriver', options=options)
+    driver = Chrome(executable_path=chromedriver_path, options=options)
     return driver
 
 def download_report(download_link: str) -> bool:
